@@ -23,6 +23,20 @@ def pipein():
         return pd.DataFrame()
 
 
+@register
+def apply(op, col1, col2, col3):
+    df = pipein()
+    if op == "+":
+        df[col3] = df[col1] + df[col2]
+    elif op == "*":
+        df[col3] = df[col1] * df[col2]
+    elif op == "-":
+        df[col3] = df[col1] - df[col2]
+    else:
+        exit("Unknown operation {}".format(op))
+    pipeout(df)
+
+
 @register
 def date(col):
     df = pipein()
@@ -138,6 +152,7 @@ pandas_computations = [
     "std",
     "var",
     "nunique",
+    "transpose",
 ]
 for attr in pandas_computations:
     register_forward(attr)
